@@ -1,5 +1,4 @@
-/*  dialogs/smartcardwindow.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2024 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
@@ -108,10 +107,10 @@ void SmartCardWindow::Private::setUpStatusBar()
     connect(ReaderStatus::instance(), &ReaderStatus::updateFinished, q, [this]() {
         statusMessage->clearMessage();
     });
-    connect(ReaderStatus::instance(), &ReaderStatus::startingLearnCards, q, [this]() {
+    connect(ReaderStatus::instance(), &ReaderStatus::startingLearnCard, q, [this]() {
         statusMessage->showMessage(i18nc("@info:status", "Importing certificates from smart cards..."));
     });
-    connect(ReaderStatus::instance(), &ReaderStatus::cardsLearned, q, [this]() {
+    connect(ReaderStatus::instance(), &ReaderStatus::cardLearned, q, [this]() {
         statusMessage->clearMessage();
     });
 
